@@ -7,12 +7,11 @@ from formatConvert.wav_pcm import wav2pcm,pcm2wav
 from G160.G160 import cal_g160
 from P563.P563 import cal_563_mos
 from PESQ.PESQ import cal_pesq
-#from .POLQA.polqa_client import  polqa_client_test
+#from POLQA.polqa_client import  polqa_client_test
 from SDR.SDR import cal_sdr
 from STI.cal_sti import cal_sti
 from STOI.STOI import cal_stoi
 from PEAQ.PEAQ import cal_peaq
-from operator import methodcaller
 from resample.resampler import resample
 import os
 import wave
